import { HttpOperationResponse } from "../httpOperationResponse";
import { WebResourceLike } from "../webResource";
import { BaseRequestPolicy, RequestPolicy, RequestPolicyFactory, RequestPolicyOptions } from "./requestPolicy";
export interface RetryData {
    retryCount: number;
    retryInterval: number;
    error?: RetryError;
}
export interface RetryError extends Error {
    message: string;
    code?: string;
    innerError?: RetryError;
}
export declare function exponentialRetryPolicy(retryCount?: number, retryInterval?: number, maxRetryInterval?: number): RequestPolicyFactory;
/**
 * Describes the Retry Mode type. Currently supporting only Exponential.
 * @enum RetryMode
 */
export declare enum RetryMode {
    Exponential = 0
}
/**
 * Options that control how to retry failed requests.
 */
export interface RetryOptions {
    /**
     * The maximum number of retry attempts.  Defaults to 3.
     */
    maxRetries?: number;
    /**
     * The amount of delay in milliseconds between retry attempts. Defaults to 30000
     * (30 seconds). The delay increases exponentially with each retry up to a maximum
     * specified by maxRetryDelayInMs.
     */
    retryDelayInMs?: number;
    /**
     * The maximum delay in milliseconds allowed before retrying an operation. Defaults
     * to 90000 (90 seconds).
     */
    maxRetryDelayInMs?: number;
    /**
     * Currently supporting only Exponential mode.
     */
    mode?: RetryMode;
}
export declare const DefaultRetryOptions: RetryOptions;
/**
 * @class
 * Instantiates a new "ExponentialRetryPolicyFilter" instance.
 */
export declare class ExponentialRetryPolicy extends BaseRequestPolicy {
    /**
     * The client retry count.
     */
    retryCount: number;
    /**
     * The client retry interval in milliseconds.
     */
    retryInterval: number;
    /**
     * The maximum retry interval in milliseconds.
     */
    maxRetryInterval: number;
    /**
     * @constructor
     * @param {RequestPolicy} nextPolicy The next RequestPolicy in the pipeline chain.
     * @param {RequestPolicyOptions} options The options for this RequestPolicy.
     * @param {number} [retryCount]        The client retry count.
     * @param {number} [retryInterval]     The client retry interval, in milliseconds.
     * @param {number} [minRetryInterval]  The minimum retry interval, in milliseconds.
     * @param {number} [maxRetryInterval]  The maximum retry interval, in milliseconds.
     */
    constructor(nextPolicy: RequestPolicy, options: RequestPolicyOptions, retryCount?: number, retryInterval?: number, maxRetryInterval?: number);
    sendRequest(request: WebResourceLike): Promise<HttpOperationResponse>;
}
//# sourceMappingURL=exponentialRetryPolicy.d.ts.map
